@@ -143,6 +143,57 @@ fn single_graph() {
 
 #[test]
 fn data_merge() -> anyhow::Result<()> {
+    let mut v1_config = CONFIG.clone();
+    v1_config.flags.push(flags::FORCE_DATA_STORE_V1.to_string());
+
+    let key0 = "9cb39c75f8d9498d8f82d92b173011f5/f/field/0-100".to_string();
+    let vector0 = create_query();
+    let elems0 = vec![Elem::new(key0.clone(), vector0.clone(), vec![], None)];
+    let key1 = "29ee1f6e4585423585f31ded0202ee3a/f/field/0-100".to_string();
+    let vector1 = create_query();
+    let elems1 = vec![Elem::new(key1.clone(), vector1.clone(), vec![], None)];
+
+    let dp0_path = tempdir()?;
+    let dp0 = segment::create(dp0_path.path(), elems0, &v1_config, HashSet::new()).unwrap();
+    assert!(dp0.data_store.as_any().downcast_ref::<DataStoreV1>().is_some());
+
+    let dp1_path = tempdir()?;
+    let dp1 = segment::create(dp1_path.path(), elems1, &v1_config, HashSet::new()).unwrap();
+    assert!(dp1.data_store.as_any().downcast_ref::<DataStoreV1>().is_some());
+
+    let work = &[&dp1, &dp0];
+
+    let dp_path = tempdir()?;
+    let dp = segment::merge(dp_path.path(), work, &v1_config).unwrap();
+    assert!(dp.data_store.as_any().downcast_ref::<DataStoreV1>().is_some());
+
+    let formula = Formula::new();
+    let result: Vec<_> = dp.search(&vector1, &formula, true, 1, &v1_config, -1.0).collect();
+    assert_eq!(result.len(), 1);
+    assert!(result[0].score() >= 0.9);
+    assert!(dp.get_paragraph(result[0].paragraph()).id() == key1);
+    let result: Vec<_> = dp.search(&vector0, &formula, true, 1, &v1_config, -1.0).collect();
+    assert_eq!(result.len(), 1);
+    assert!(result[0].score() >= 0.9);
+    assert!(dp.get_paragraph(result[0].paragraph()).id() == key0);
+    let mut dp0 = segment::open(dp0.metadata, &v1_config).unwrap();
+    let mut dp1 = segment::open(dp1.metadata, &v1_config).unwrap();
+    dp0.apply_deletion(&key0);
+    dp0.apply_deletion(&key1);
+    dp1.apply_deletion(&key0);
+    dp1.apply_deletion(&key1);
+    let work = &[&dp1, &dp0];
+
+    let dp_path = tempdir()?;
+    let dp = segment::merge(dp_path.path(), work, &v1_config).unwrap();
+
+    assert_eq!(dp.metadata.records, 0);
+
+    Ok(())
+}
+
+#[test]
+fn data_merge_v2() -> anyhow::Result<()> {
     let key0 = "9cb39c75f8d9498d8f82d92b173011f5/f/field/0-100".to_string();
     let vector0 = create_query();
     let elems0 = vec![Elem::new(key0.clone(), vector0.clone(), vec![], None)];
@@ -152,17 +203,17 @@ fn data_merge() -> anyhow::Result<()> {
 
     let dp0_path = tempdir()?;
     let dp0 = segment::create(dp0_path.path(), elems0, &CONFIG, HashSet::new()).unwrap();
-    assert!(dp0.data_store.as_any().downcast_ref::<DataStoreV1>().is_some());
+    assert!(dp0.data_store.as_any().downcast_ref::<DataStoreV2>().is_some());
 
     let dp1_path = tempdir()?;
     let dp1 = segment::create(dp1_path.path(), elems1, &CONFIG, HashSet::new()).unwrap();
-    assert!(dp1.data_store.as_any().downcast_ref::<DataStoreV1>().is_some());
+    assert!(dp1.data_store.as_any().downcast_ref::<DataStoreV2>().is_some());
 
     let work = &[&dp1, &dp0];
 
     let dp_path = tempdir()?;
     let dp = segment::merge(dp_path.path(), work, &CONFIG).unwrap();
-    assert!(dp.data_store.as_any().downcast_ref::<DataStoreV1>().is_some());
+    assert!(dp.data_store.as_any().downcast_ref::<DataStoreV2>().is_some());
 
     let formula = Formula::new();
     let result: Vec<_> = dp.search(&vector1, &formula, true, 1, &CONFIG, -1.0).collect();
@@ -189,57 +240,6 @@ fn data_merge() -> anyhow::Result<()> {
     Ok(())
 }
 
-#[test]
-fn data_merge_v2() -> anyhow::Result<()> {
-    let key0 = "9cb39c75f8d9498d8f82d92b173011f5/f/field/0-100".to_string();
-    let vector0 = create_query();
-    let elems0 = vec![Elem::new(key0.clone(), vector0.clone(), vec![], None)];
-    let key1 = "29ee1f6e4585423585f31ded0202ee3a/f/field/0-100".to_string();
-    let vector1 = create_query();
-    let elems1 = vec![Elem::new(key1.clone(), vector1.clone(), vec![], None)];
-
-    let mut v2_config = CONFIG.clone();
-    v2_config.flags.push(flags::DATA_STORE_V2.to_string());
-
-    let dp0_path = tempdir()?;
-    let dp0 = segment::create(dp0_path.path(), elems0, &v2_config, HashSet::new()).unwrap();
-    assert!(dp0.data_store.as_any().downcast_ref::<DataStoreV2>().is_some());
-
-    let dp1_path = tempdir()?;
-    let dp1 = segment::create(dp1_path.path(), elems1, &v2_config, HashSet::new()).unwrap();
-    assert!(dp1.data_store.as_any().downcast_ref::<DataStoreV2>().is_some());
-
-    let work = &[&dp1, &dp0];
-
-    let dp_path = tempdir()?;
-    let dp = segment::merge(dp_path.path(), work, &v2_config).unwrap();
-    assert!(dp.data_store.as_any().downcast_ref::<DataStoreV2>().is_some());
-
-    let formula = Formula::new();
-    let result: Vec<_> = dp.search(&vector1, &formula, true, 1, &v2_config, -1.0).collect();
-    assert_eq!(result.len(), 1);
-    assert!(result[0].score() >= 0.9);
-    assert!(dp.get_paragraph(result[0].paragraph()).id() == key1);
-    let result: Vec<_> = dp.search(&vector0, &formula, true, 1, &v2_config, -1.0).collect();
-    assert_eq!(result.len(), 1);
-    assert!(result[0].score() >= 0.9);
-    assert!(dp.get_paragraph(result[0].paragraph()).id() == key0);
-    let mut dp0 = segment::open(dp0.metadata, &v2_config).unwrap();
-    let mut dp1 = segment::open(dp1.metadata, &v2_config).unwrap();
-    dp0.apply_deletion(&key0);
-    dp0.apply_deletion(&key1);
-    dp1.apply_deletion(&key0);
-    dp1.apply_deletion(&key1);
-    let work = &[&dp1, &dp0];
-
-    let dp_path = tempdir()?;
-    let dp = segment::merge(dp_path.path(), work, &v2_config).unwrap();
-
-    assert_eq!(dp.metadata.records, 0);
-
-    Ok(())
-}
-
 #[test]
 fn data_merge_mixed() -> anyhow::Result<()> {
     let key0 = "9cb39c75f8d9498d8f82d92b173011f5/f/field/0-100".to_string();
@@ -249,34 +249,34 @@ fn data_merge_mixed() -> anyhow::Result<()> {
     let vector1 = create_query();
     let elems1 = vec![Elem::new(key1.clone(), vector1.clone(), vec![], None)];
 
-    let mut v2_config = CONFIG.clone();
-    v2_config.flags.push(flags::DATA_STORE_V2.to_string());
+    let mut v1_config = CONFIG.clone();
+    v1_config.flags.push(flags::FORCE_DATA_STORE_V1.to_string());
 
     let dp0_path = tempdir()?;
-    let dp0 = segment::create(dp0_path.path(), elems0, &CONFIG, HashSet::new()).unwrap();
+    let dp0 = segment::create(dp0_path.path(), elems0, &v1_config, HashSet::new()).unwrap();
     assert!(dp0.data_store.as_any().downcast_ref::<DataStoreV1>().is_some());
 
     let dp1_path = tempdir()?;
-    let dp1 = segment::create(dp1_path.path(), elems1, &v2_config, HashSet::new()).unwrap();
+    let dp1 = segment::create(dp1_path.path(), elems1, &CONFIG, HashSet::new()).unwrap();
     assert!(dp1.data_store.as_any().downcast_ref::<DataStoreV2>().is_some());
 
     let work = &[&dp1, &dp0];
 
     let dp_path = tempdir()?;
-    let dp = segment::merge(dp_path.path(), work, &v2_config).unwrap();
+    let dp = segment::merge(dp_path.path(), work, &CONFIG).unwrap();
     assert!(dp.data_store.as_any().downcast_ref::<DataStoreV2>().is_some());
 
     let formula = Formula::new();
-    let result: Vec<_> = dp.search(&vector1, &formula, true, 1, &v2_config, -1.0).collect();
+    let result: Vec<_> = dp.search(&vector1, &formula, true, 1, &CONFIG, -1.0).collect();
     assert_eq!(result.len(), 1);
     assert!(result[0].score() >= 0.9);
     assert!(dp.get_paragraph(result[0].paragraph()).id() == key1);
-    let result: Vec<_> = dp.search(&vector0, &formula, true, 1, &v2_config, -1.0).collect();
+    let result: Vec<_> = dp.search(&vector0, &formula, true, 1, &CONFIG, -1.0).collect();
     assert_eq!(result.len(), 1);
     assert!(result[0].score() >= 0.9);
     assert!(dp.get_paragraph(result[0].paragraph()).id() == key0);
-    let mut dp0 = segment::open(dp0.metadata, &v2_config).unwrap();
-    let mut dp1 = segment::open(dp1.metadata, &v2_config).unwrap();
+    let mut dp0 = segment::open(dp0.metadata, &CONFIG).unwrap();
+    let mut dp1 = segment::open(dp1.metadata, &CONFIG).unwrap();
     dp0.apply_deletion(&key0);
     dp0.apply_deletion(&key1);
     dp1.apply_deletion(&key0);
@@ -284,7 +284,7 @@ fn data_merge_mixed() -> anyhow::Result<()> {
     let work = &[&dp1, &dp0];
 
     let dp_path = tempdir()?;
-    let dp = segment::merge(dp_path.path(), work, &v2_config).unwrap();
+    let dp = segment::merge(dp_path.path(), work, &CONFIG).unwrap();
 
     assert_eq!(dp.metadata.records, 0);
 
