@@ -145,7 +145,7 @@ mod tests {
         use std::collections::{HashMap, HashSet};
 
         use nidx_types::Seq;
-        use nidx_vector::config::VectorConfig;
+        use nidx_vector::config::{VectorCardinality, VectorConfig};
         use serde_json::json;
         use uuid::Uuid;
 
@@ -161,6 +161,7 @@ mod tests {
             normalize_vectors: false,
             vector_type: nidx_vector::config::VectorType::DenseF32 { dimension: 3 },
             flags: vec![],
+            vector_cardinality: VectorCardinality::Single,
         };
 
         fn merge_scheduler() -> MergeScheduler {
